==> qmmp_0.8.1.orig.tar.bz2: qmmp-0.8.1/src/plugins/Input/cdaudio/translations/cdaudio_plugin_sr_BA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sr_BA">
<context>
    <name>DecoderCDAudioFactory</name>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="45"/>
        <source>CD Audio Plugin</source>
        <translation>Музички диск</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="90"/>
        <source>About CD Audio Plugin</source>
        <translation>О прикључку за музички диск</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="91"/>
        <source>Qmmp CD Audio Plugin</source>
        <translation>Кумп прикључак за музички диск</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="92"/>
        <source>Compiled against libcdio-%1 and libcddb-%2</source>
        <translation>Компилован на libcdio-%1 и libcddb-%2</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="94"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Аутор: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="95"/>
        <source>Usage: open cdda:/// using Add URL dialog or command line</source>
        <translation>Употреба: отворите cdda:/// користећи дијалог за додавање УРЛ-а или командну линију</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>CD Audio Plugin Settings</source>
        <translation>Поставке музичког диска</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Override device:</source>
        <translation>Дефиниши уређај:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="42"/>
        <source>Limit cd speed:</source>
        <translation>Ограничи брзину диска:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>Use cd-text</source>
        <translation>Користи ЦД-текст</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="69"/>
        <source>CDDB</source>
        <translation>ЦДДБ</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <source>Use HTTP instead of CDDBP</source>
        <translation>ХТТП умјесто ЦДДБП</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="88"/>
        <source>Server:</source>
        <translation>Сервер:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="95"/>
        <source>Path:</source>
        <translation>Путања:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="105"/>
        <source>Port:</source>
        <translation>Порт:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="117"/>
        <source>Clear CDDB cache</source>
        <translation>Очисти ЦДДБ кеш</translation>
    </message>
</context>
</TS>

==> qmmp-0.12.18.tar.bz2: qmmp-0.12.18/src/plugins/Input/cdaudio/translations/cdaudio_plugin_sr_BA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sr_BA">
<context>
    <name>DecoderCDAudioFactory</name>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="51"/>
        <source>CD Audio Plugin</source>
        <translation>Музички диск</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="98"/>
        <source>About CD Audio Plugin</source>
        <translation>О прикључку за музички диск</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="99"/>
        <source>Qmmp CD Audio Plugin</source>
        <translation>Кумп прикључак за музички диск</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="100"/>
        <source>Compiled against libcdio-%1 and libcddb-%2</source>
        <translation>Компилован на libcdio-%1 и libcddb-%2</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="102"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Аутор: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="103"/>
        <source>Usage: open cdda:/// using Add URL dialog or command line</source>
        <translation>Употреба: отворите cdda:/// користећи дијалог за додавање УРЛ-а или командну линију</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>CD Audio Plugin Settings</source>
        <translation>Поставке музичког диска</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Override device:</source>
        <translation>Дефиниши уређај:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="42"/>
        <source>Limit cd speed:</source>
        <translation>Ограничи брзину диска:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>Use cd-text</source>
        <translation>Користи ЦД-текст</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="69"/>
        <source>CDDB</source>
        <translation>ЦДДБ</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <source>Use HTTP instead of CDDBP</source>
        <translation>ХТТП умјесто ЦДДБП</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="88"/>
        <source>Server:</source>
        <translation>Сервер:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="95"/>
        <source>Path:</source>
        <translation>Путања:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="105"/>
        <source>Port:</source>
        <translation>Порт:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="117"/>
        <source>Clear CDDB cache</source>
        <translation>Очисти ЦДДБ кеш</translation>
    </message>
</context>
</TS>
